==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Виконано</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Обмеження осі...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>задати вісь обмежену двома об'єктами</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Самотестування...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Запускає самотестування для перевірки того, що програма працює належним чином</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Креслення</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Ескіз</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Трасування променів</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Креслення</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Базуючись на ескізі</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Примітиви</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Параметричний</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Поведінка об'єкту</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Інструмент Струна</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Виконано</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Обмеження осі...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>задати вісь обмежену двома об'єктами</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Самотестування...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Запускає самотестування для перевірки того, що програма працює належним чином</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Креслення</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Ескіз</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Трасування променів</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Креслення</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Базуючись на ескізі</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Примітиви</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Параметричний</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Поведінка об'єкту</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Інструмент Струна</translation>
    </message>
  </context>
</TS>
